@@ -76,8 +76,8 @@ module HTTP2
       @local_settings  = DEFAULT_CONNECTION_SETTINGS.merge(settings)
       @remote_settings = SPEC_DEFAULT_CONNECTION_SETTINGS.dup
 
-      @compressor   = Header::Compressor.new(settings)
-      @decompressor = Header::Decompressor.new(settings)
+      @compressor   = Header::Compressor.new(**settings)
+      @decompressor = Header::Decompressor.new(**settings)
 
       @active_stream_count = 0
       @streams = {}
@@ -539,7 +539,7 @@ module HTTP2
         # Process pending settings we have sent.
         [@pending_settings.shift, :local]
       else
-        connection_error(check) if validate_settings(@remote_role, frame[:payload])
+        connection_error if validate_settings(@remote_role, frame[:payload])
         [frame[:payload], :remote]
       end
 
@@ -593,7 +593,8 @@ module HTTP2
           # nothing to do
 
         when :settings_max_frame_size
-          # nothing to do
+          # update framer max_frame_size
+          @framer.max_frame_size = v
 
           # else # ignore unknown settings
         end
@@ -674,7 +675,7 @@ module HTTP2
     def activate_stream(id: nil, **args)
       connection_error(msg: 'Stream ID already exists') if @streams.key?(id)
 
-      stream = Stream.new({ connection: self, id: id }.merge(args))
+      stream = Stream.new(**{ connection: self, id: id }.merge(args))
 
       # Streams that are in the "open" state, or either of the "half closed"
       # states count toward the maximum number of streams that an endpoint is
