@@ -50,6 +50,22 @@ RSpec.describe HTTP2::Connection do
       expect(@conn.remote_settings[:settings_header_table_size]).to eq 256
     end
 
+    it 'should reflect settings_max_frame_size recevied from peer' do
+      settings = settings_frame
+      settings[:payload] = [[:settings_max_frame_size, 16_385]]
+
+      @conn << f.generate(settings)
+
+      frame = {
+        length: 16_385,
+        type: :data,
+        flags: [:end_stream],
+        stream: 1,
+        payload: 'a' * 16_385,
+      }
+      expect { @conn.send(frame) }.not_to raise_error(CompressionError)
+    end
+
     it 'should send SETTINGS ACK when SETTINGS is received' do
       settings = settings_frame
       settings[:payload] = [[:settings_header_table_size, 256]]
@@ -369,7 +385,7 @@ RSpec.describe HTTP2::Connection do
       stream = @conn.new_stream
 
       expect do
-        stream.headers('name' => Float::INFINITY)
+        stream.headers({ 'name' => Float::INFINITY })
       end.to raise_error(CompressionError)
     end
 
@@ -397,10 +413,10 @@ RSpec.describe HTTP2::Connection do
       end
 
       stream = @conn.new_stream
-      stream.headers(':method' => 'get',
-                     ':scheme' => 'http',
-                     ':authority' => 'www.example.org',
-                     ':path'   => '/resource')
+      stream.headers({ ':method' => 'get',
+                       ':scheme' => 'http',
+                       ':authority' => 'www.example.org',
+                       ':path'   => '/resource' })
     end
 
     it 'should generate CONTINUATION if HEADERS is too long' do
